<?php
/* ***** BEGIN LICENSE BLOCK ***** 
 *
 * The contents of this file are copyright
 * Chris Pollett 2009.
 *
 * Use of this file is permitted provided:
 *
 * (a) this copyright notice is retained, 
 *     including in derived works.
 *
 * (b) any changes to this file are not
 *     publicly made available or used 
 *     for commercial purposes without 
 *     the express consent of Chris Pollett
 *     
 *  ***** END LICENSE BLOCK ***** */

/**
 * datasource_manager.php
 * 
 * This abstract class defines the interface through which
 * the genealogy program communicates with a database and the
 * filesystem. Currently the only subclass of this class is MysqlManager
 * However, one could easily add support for other DBMSs
 *
 * @author Chris Pollett
 *
 * @package mysearch
 */

abstract class DatasourceManager
{
 
   public function __construct() {}
  
   /**
    *  Connects to a DBMS using data in config.php
	*  Connects to the correct DB on that system
	*  
    */   

   public abstract function connect();
  

   /**
    *  Closes connections to DBMS
	*  
    */  
   public abstract function disconnect();
  

   /**
    *  Executes the supplied sql command on the database
	*  (either query or data manipulation statement)
	*
	*  @param $sql - SQL statement to execute  
    */    
   public abstract function execute($sql); 

   /**
    *  @returns the number of rows affected by the last
	*  insert, update, delete  
    */    
   public abstract function affected_rows();


   /**
    *  @return the ID generated by the last insert statement
	*  if table has an auto increment key column   
    */   
   public abstract function insert_id();  

   /**
    *  @param $result - result set reference of a query
	*
    *  @return the next row from the result set as an
	*  associative array in the form column_name => value
    */	    
   public abstract function fetch_array($result);

   /**
    *  Used to escape strings before insertion in the
	*  database to avoid SQL injection
	*  
	*  @param $str - string to escape
    */   
   public abstract function escape_string($str);   

   /**
    * Recursively delete a directory (from PHP manual site)
    *
    * @param string $dir Directory name
    * @param boolean $deleteRootToo Delete specified top-level directory as well
    */
   public function unlinkRecursive($dir, $deleteRootToo = true)
   {
      if(!$dh = @opendir($dir))
      {
         return;
      }
      while (false !== ($obj = readdir($dh)))
      {
         if($obj == '.' || $obj == '..')
         {
             continue;
         }

         if (!@unlink($dir . '/' . $obj))
         {
             $this->unlinkRecursive($dir.'/'.$obj, true);
         }
      }

     closedir($dh);
   
     if ($deleteRootToo)
     {
         @rmdir($dir);
     }
   
     return;
   }
} 
?>

